package Acme::PERLANCAR::Dummy::POD;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-07-09'; # DATE
our $DIST = 'Acme-PERLANCAR-Dummy-POD'; # DIST
our $VERSION = '0.003'; # VERSION

1;
# ABSTRACT: Dummy distribution for various POD testing

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::PERLANCAR::Dummy::POD - Dummy distribution for various POD testing

=head1 VERSION

This document describes version 0.003 of Acme::PERLANCAR::Dummy::POD (from Perl distribution Acme-PERLANCAR-Dummy-POD), released on 2021-07-09.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-PERLANCAR-Dummy-POD>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-PERLANCAR-Dummy-POD>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-PERLANCAR-Dummy-POD>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
